#include <Adafruit_GFX.h>
#include <Adafruit_SSD1331.h>
#include <SPI.h>

#define SCREEN_WIDTH 96 // OLED display width, in pixels
#define SCREEN_HEIGHT 64 // OLED display height, in pixels

// Declaration for SSD1306 display connected using software SPI 
#define SCLK 22
#define MOSI 21
#define CS   16
#define RST  4
#define DC   2
Adafruit_SSD1331 display = Adafruit_SSD1331(CS, DC, MOSI, SCLK, RST);

// Color definitions
#define	BLACK           0x0000
#define	BLUE            0x001F
#define	RED             0xF800
#define	GREEN           0x07E0
#define CYAN            0x07FF
#define MAGENTA         0xF81F
#define YELLOW          0xFFE0
#define WHITE           0xFFFF

// 'logo_RGB', 96x64px
const uint16_t logo [] PROGMEM = {
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xad55, 0x6a24, 0x6a44, 0x9cd3, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x9cf3, 0x6a65, 0x6a24, 0xad55, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x632c, 0xf403, 0xfc23, 0x7a63, 0xb595, 0xffff, 0xffdf, 0xf79e, 0xbdf7, 0x8c71, 
	0x9491, 0xbdf7, 0xf79e, 0xffdf, 0xffff, 0xb5b6, 0x6a23, 0xfc23, 0xf423, 0x632c, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x9cf3, 0x59c3, 0xebe3, 0xec03, 0x7a64, 0x7bef, 0x5acb, 0x2945, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x2945, 0x5acb, 0x7bef, 0x6a24, 0xebe3, 0xf403, 0x7223, 0xad54, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x9491, 0x6a24, 0xe3e3, 0x8263, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 
	0x2103, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x92a3, 0xec03, 0x8284, 0x8430, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xb596, 0x6b4d, 0xd699, 0xffff, 0xffff, 0xffdf, 0x9492, 0x3943, 0x20e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 0x5b0c, 
	0x5acb, 0x2103, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4163, 0x94b2, 0xffdf, 0xffff, 0xffff, 0xd6ba, 0x6b4c, 0xad75, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xd6ba, 0x6a23, 0xd3a3, 0x6266, 0xce79, 0xffff, 0xffdf, 0x8430, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x5aec, 0x73cf, 
	0x73af, 0x52aa, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x8430, 0xf7be, 0xffff, 0xce79, 0x6246, 0xc363, 0x59e3, 0xdefb, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xb5b6, 0x7a43, 0xf423, 0xe3e3, 0x49c5, 0xce59, 0x8430, 0x2103, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x5b0c, 0x73cf, 0x5aec, 
	0x4208, 0x73ae, 0x52cb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2103, 0x8430, 0xd6ba, 0x49e5, 0xe3e3, 0xfc23, 0x7a63, 0xc618, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0x6b4c, 0x92a3, 0xf403, 0xe3e3, 0x3984, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x5b0c, 0x73cf, 0x5b0c, 0x2124, 
	0x18e3, 0x4249, 0x73ae, 0x52aa, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x39a5, 0xdba3, 0xf423, 0x9ac3, 0x736d, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xf7be, 0x4208, 0x92a3, 0x7223, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x5b0c, 0x73cf, 0x5b0c, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x4228, 0x73af, 0x52cb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x7223, 0x9ac3, 0x4a48, 0xffdf, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xa513, 0x7b08, 0x734c, 
	0xdefb, 0xffff, 0xffff, 0xf7be, 0x39e7, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x5b0c, 0x73cf, 0x5b0c, 0x2124, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x4228, 0x73ae, 0x52cb, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x39c6, 0xffdf, 0xffff, 0xffff, 0xdefb, 
	0x734c, 0x72e8, 0xa514, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x8308, 0xfc23, 0xc363, 
	0x4a07, 0xe73c, 0xffdf, 0x6b6d, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 0x5aec, 0x73cf, 0x5b0c, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4228, 0x73ae, 0x52aa, 0x2103, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x5acb, 0xf7be, 0xef5d, 0x5268, 
	0xc363, 0xfc23, 0x7ae8, 0xffdf, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x6b0b, 0xbb43, 0xfc23, 
	0xc363, 0x5248, 0x6b4d, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 0x5b0c, 0x73cf, 0x5aec, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4208, 0x73ae, 0x5acb, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x630b, 0x5248, 0xc363, 
	0xfc23, 0xc343, 0x6b0b, 0xffdf, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xd69a, 0x4a07, 0xc343, 
	0xf403, 0x61e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x5aeb, 0x73cf, 0x5b0c, 0x2103, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4249, 0x73ae, 0x52aa, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x51c3, 0xec03, 
	0xc363, 0x5247, 0xe71c, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xdedb, 0xc618, 0xffff, 0xffff, 0xffff, 0xe73c, 0x5248, 
	0x61e3, 0x20e3, 0x18e3, 0x18e3, 0x18e3, 0x2103, 0x5b0c, 0x73cf, 0x5aec, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4208, 0x73ae, 0x5acb, 0x2103, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x59c3, 
	0x5247, 0xe73c, 0xffff, 0xffff, 0xffff, 0xbdf7, 0xd6ba, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xb596, 0x6203, 0x7a63, 0x7bad, 0xffdf, 0xffff, 0xffdf, 0x6b4d, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x5b0c, 0x73cf, 0x5b0c, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4249, 0x73ae, 0x52aa, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x6b4d, 0xf7be, 0xffff, 0xffdf, 0x7bce, 0x7a63, 0x61e3, 0xbdd7, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x630b, 0xc343, 0xfc23, 0xa2e3, 0x52aa, 0xffdf, 0x6b6d, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x5b0c, 0x73cf, 0x5b0c, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4208, 0x73ae, 0x52cb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x6b6d, 0xffdf, 0x5aeb, 0x92c3, 0xfc23, 0xbb63, 0x6b6d, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xc638, 0x51e5, 0xdba3, 0xfc23, 0xa2c3, 0x4207, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x2124, 0x5b0c, 0x73cf, 0x5b0c, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4228, 0x73ae, 0x52cb, 0x2104, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x4207, 0x8a83, 0xf423, 0xebe3, 0x6245, 0xd69a, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xc618, 0x3164, 0xdba3, 0x92a3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x2103, 0x5b0c, 0x73cf, 0x5b0c, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4228, 0x73af, 0x52aa, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x7223, 0xe3e3, 0x41a4, 0xce59, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xad55, 0x632c, 0xad75, 0xffff, 0xffff, 0xffff, 0xc618, 0x3984, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x2124, 0x5b0c, 0x73cf, 0x5b0c, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x31a6, 0x528a, 0x2965, 0x18e3, 0x18e3, 0x18e3, 0x4228, 0x73ae, 0x52cb, 0x2104, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x3984, 0xce59, 0xffff, 0xffff, 0xffff, 0xb595, 0x6b4c, 0xa514, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0x6204, 0xf423, 0x6a03, 0xa534, 0xffdf, 0xffdf, 0x8430, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 
	0x5aeb, 0x73cf, 0x5b0c, 0x18e3, 0x2965, 0x4228, 0x632c, 0x9cd3, 0xa514, 0x8c51, 0x4207, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x2103, 0x632c, 0xe71b, 0xffff, 0xffff, 0xffff, 0x94b2, 0x2104, 0x18e3, 0x18e3, 0x4249, 0x73ae, 0x52aa, 
	0x2103, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x6b6d, 0xf7be, 0xffff, 0xad55, 0x6a03, 0xf423, 0x6a44, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0x59e4, 0xfc23, 0xec03, 0x8284, 0xa514, 0x8430, 0x2103, 0x18e3, 0x18e3, 0x18e3, 0x2104, 0x5b0c, 
	0x73cf, 0x5aec, 0x2124, 0x18e3, 0xbdd7, 0xffdf, 0xffff, 0xffff, 0xffff, 0xffff, 0x9cf3, 0x18e3, 0x18e3, 0x4a69, 0x73ae, 0x73ae, 
	0x4228, 0x18e3, 0x2104, 0xad75, 0xffdf, 0xffff, 0xffff, 0xffff, 0xffff, 0xffdf, 0x7bcf, 0x18e3, 0x18e3, 0x18e3, 0x4208, 0x73ae, 
	0x5acb, 0x2103, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x738e, 0xad55, 0x8284, 0xec03, 0xfc23, 0x6a45, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0x8c71, 0x6203, 0xebe3, 0xec03, 0x4163, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x5aec, 0x73cf, 
	0x5b0c, 0x2104, 0x18e3, 0x18e3, 0xd69a, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x8c51, 0x39c7, 0xc617, 0xffff, 0xffff, 0xffff, 
	0xf7be, 0x738e, 0x7bef, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xf79e, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x4249, 
	0x73ae, 0x52aa, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x3943, 0xebe3, 0xf403, 0x7243, 0x94b2, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffdf, 0xa534, 0x6a03, 0x9ac3, 0x20e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x5b0c, 0x73cf, 0x5aec, 
	0x2103, 0x18e3, 0x18e3, 0x18e3, 0xd69a, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x6b4d, 0xdedb, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffdf, 0xf7be, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x52aa, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x4208, 0x73ae, 0x52cb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x8a83, 0x8263, 0xad55, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x738e, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x5b0c, 0x73cf, 0x5b0c, 0x2124, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0xc638, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xf79e, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xdedb, 0x630c, 0xce59, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x632c, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x4249, 0x73ae, 0x52aa, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x738d, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffdf, 0x5acb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x5b0c, 0x73cf, 0x5b0c, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0xbdd6, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xf7be, 0x3185, 0x18e3, 0x7bcf, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x6b6d, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x4228, 0x73af, 0x52cb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x528a, 0xffdf, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xf79e, 0x2945, 0x18e3, 0x18e3, 0x2124, 0x5b0c, 0x73cf, 0x5b0c, 0x2124, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0xad55, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x632c, 0x2965, 0xe71b, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xce59, 0x2104, 0x18e3, 0x7bcf, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x6b4d, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x4228, 0x73ae, 0x52cb, 0x2104, 0x18e3, 0x18e3, 0x2945, 0xef5d, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xad75, 0x18e3, 0x18e3, 0x2104, 0x5aec, 0x73cf, 0x5b0c, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x9cd2, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xa534, 0x18e3, 0x18e3, 0xc618, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xb5b6, 0x18e3, 0x18e3, 0x8410, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x630c, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4228, 0x73ae, 0x52aa, 0x2103, 0x18e3, 0x18e3, 0xb5b6, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x8430, 0x18e3, 0x2104, 0x5b0c, 0x73cf, 0x634d, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x8c51, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x4228, 0x18e3, 0x18e3, 0xce79, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xb596, 0x18e3, 0x18e3, 0xad75, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x5aeb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4228, 0x73cf, 0x5acb, 0x2104, 0x18e3, 0x8c71, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x8430, 0x18e3, 0x2104, 0x5acb, 0x73af, 0x73cf, 0x31a6, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x7bef, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x39c6, 0x18e3, 0x18e3, 0xdedb, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xad55, 0x18e3, 0x18e3, 0xe73c, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x4a69, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x632c, 0x73af, 0x5aeb, 0x2104, 0x18e3, 0x8c71, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xad55, 0x18e3, 0x18e3, 0x2104, 0x52aa, 0x73af, 0x6b8e, 0x2985, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x6b4d, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x39c6, 0x18e3, 0x18e3, 0xef7d, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xa534, 0x18e3, 0x2945, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x3186, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x630c, 0x73af, 0x52cb, 0x2104, 0x18e3, 0x18e3, 0xbdd7, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xef5d, 0x2124, 0x18e3, 0x18e3, 0x2104, 0x52cb, 0x73af, 0x73cf, 0x31a6, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x5aeb, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x39c6, 0x18e3, 0x18e3, 0xffdf, 0xffff, 0xffff, 
	0xffff, 0xffff, 0x8c51, 0x18e3, 0x4a49, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffdf, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x2124, 0x632c, 0x73af, 0x5aeb, 0x2124, 0x18e3, 0x18e3, 0x2945, 0xef5d, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffdf, 0x528a, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x52aa, 0x73cf, 0x73ae, 0x2985, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x4a49, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x39c6, 0x18e3, 0x31a6, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0x6b4d, 0x18e3, 0x632c, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xd69a, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x632c, 0x73cf, 0x52cb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x52aa, 0xffdf, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x73ae, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x52cb, 0x73af, 0x6bae, 0x31a6, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x39c7, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x39c6, 0x18e3, 0x6b6d, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0x528a, 0x18e3, 0x8430, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xa514, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x2124, 0x630c, 0x73af, 0x52cb, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x7bcf, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xbdf7, 0x8263, 0xa2e3, 0x20e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x52cb, 0x73af, 0x73cf, 
	0x3186, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x39c6, 0x18e3, 0x9cd3, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0x2944, 0x18e3, 0x9cf3, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x6b6d, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2103, 
	0x632c, 0x73af, 0x5aeb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x8a83, 0x6a24, 0xb595, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xa514, 0x8263, 0xec03, 0xebe3, 0x4163, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x52aa, 0x73af, 
	0x6b8e, 0x31a6, 0x18e3, 0x18e3, 0x18e3, 0xef7d, 0xffff, 0xffff, 0xffff, 0xf7be, 0x31a6, 0x18e3, 0xdedb, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xdefb, 0x18e3, 0x18e3, 0xbdf7, 0xffff, 0xffff, 0xffff, 0xffff, 0xffdf, 0x39e7, 0x18e3, 0x18e3, 0x18e3, 0x2104, 0x5b0c, 
	0x73af, 0x52cb, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x3143, 0xe3e3, 0xebe3, 0x6a03, 0x9cd3, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0x6a24, 0xfc23, 0xf403, 0x8284, 0x9492, 0x5aeb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2103, 0x5acb, 
	0x73af, 0x73cf, 0x31a6, 0x18e3, 0x18e3, 0xb5b6, 0xef5d, 0xe73c, 0xdefb, 0xbdd7, 0x2965, 0x18e3, 0x7bce, 0x9cd2, 0xb596, 0xce79, 
	0xdedb, 0x94b2, 0x18e3, 0x18e3, 0xdefb, 0xffff, 0xffff, 0xffff, 0xffff, 0xe71c, 0x2965, 0x18e3, 0x18e3, 0x2124, 0x632c, 0x73af, 
	0x5aeb, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x73ae, 0x9492, 0x7a64, 0xf403, 0xfc23, 0x6a45, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0x59e3, 0xebe3, 0x6a03, 0x9cd3, 0xffdf, 0xf79e, 0x5acb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 
	0x52aa, 0x73af, 0x6b8e, 0x3186, 0x18e3, 0x3186, 0x39c6, 0x3186, 0x2944, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x2124, 0x2124, 0x18e3, 0x2104, 0xef5d, 0xffff, 0xffff, 0xffff, 0xffff, 0xce79, 0x2124, 0x18e3, 0x18e3, 0x630c, 0x73af, 0x52cb, 
	0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x73ae, 0xf7be, 0xffdf, 0x9491, 0x6a03, 0xf403, 0x7264, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0x94b2, 0x52aa, 0xa534, 0xffff, 0xffff, 0xffff, 0xce79, 0x3123, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x2104, 0x5acb, 0x73af, 0x73cf, 0x31a6, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x39e7, 0x5acb, 0x738e, 0x5aeb, 0x18e3, 0x2124, 0x632d, 0x73af, 0x5aeb, 0x2104, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x41a4, 0xce79, 0xffff, 0xffff, 0xffff, 0x9cf3, 0x5acb, 0x9cf3, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffdf, 0xffff, 0xffff, 0xffff, 0xce79, 0x49e5, 0xdba3, 0x7223, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x2103, 0x52aa, 0x73af, 0x6bae, 0x2985, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x632c, 0x73cf, 0x52cb, 0x2103, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x9ac3, 0xe3c3, 0x49c5, 0xce58, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xd69a, 0x6246, 0xe3e3, 0xf403, 0x8a83, 0x39c7, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x2124, 0x52cb, 0x73af, 0x73ae, 0x31a6, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x632c, 0x73af, 0x5acb, 0x2124, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x41e7, 0x92a3, 0xf403, 0xebe3, 0x6266, 0xd69a, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x632c, 0xcb83, 0xfc23, 0x9ac3, 0x4a69, 0xffff, 0x632c, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x52cb, 0x73cf, 0x73cf, 0x2985, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x632d, 0x73cf, 0x5acb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x73ae, 0xf7be, 0x4208, 0x92a3, 0xfc23, 0xc363, 0x6b4c, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xad55, 0x59c3, 0x7a43, 0x736d, 0xffff, 0xffff, 0xf7be, 0x632c, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x52aa, 0x73af, 0x6b8e, 0x31a6, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x630c, 0x73af, 0x52cb, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x632c, 0xf7be, 0xffff, 0xf7be, 0x6b4c, 0x7a43, 0x59c3, 0xb5b6, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xce59, 0xbdf7, 0xffff, 0xffff, 0xffff, 0xef5d, 0x5268, 
	0x6a03, 0x20e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x52cb, 0x73af, 0x73cf, 0x31a6, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 0x632c, 0x73af, 0x5aeb, 0x2103, 0x18e3, 0x18e3, 0x18e3, 0x20e3, 0x7223, 
	0x4a27, 0xe73c, 0xffff, 0xffff, 0xffff, 0xb596, 0xce79, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xdefb, 0x5268, 0xc363, 
	0xf403, 0x6a03, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 0x52aa, 0x73af, 0x6b8e, 0x31a6, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2103, 0x5b0c, 0x73af, 0x52cb, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x59e3, 0xf403, 
	0xcb83, 0x5268, 0xdefb, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x6b2c, 0xc363, 0xfc23, 
	0xc363, 0x5247, 0x5aeb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 0x5acb, 0x73af, 0x73cf, 0x31a6, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x632c, 0x73af, 0x5aeb, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x6b4c, 0x41e7, 0xb323, 
	0xfc23, 0xd383, 0x6b2b, 0xffdf, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x6ac8, 0xfc23, 0xc343, 
	0x5247, 0xe73c, 0xf79e, 0x52aa, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 0x52aa, 0x73af, 0x6b8e, 0x2985, 0x18e3, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x630c, 0x73af, 0x52cb, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x8c71, 0xf7be, 0xe73c, 0x4a28, 
	0xab03, 0xfc23, 0x7ae8, 0xffdf, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x9492, 0x5a67, 0x62ea, 
	0xe71c, 0xffff, 0xffff, 0xffdf, 0x39c6, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 0x52cb, 0x73af, 0x73cf, 0x31a6, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x2124, 0x632c, 0x73af, 0x5aeb, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x5268, 0xffdf, 0xffff, 0xffff, 0xdefb, 
	0x5aaa, 0x6287, 0x94b2, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xf7be, 0xffdf, 
	0xffff, 0xffff, 0xffdf, 0x5aeb, 0x8a83, 0x7223, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x52aa, 0x73cf, 0x73ae, 0x2985, 0x18e3, 
	0x18e3, 0x18e3, 0x632c, 0x73cf, 0x52cb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x92a3, 0xa2e3, 0x52aa, 0xffdf, 0xffff, 0xffff, 
	0xffdf, 0xf7be, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0x7bce, 0x92c3, 0xf423, 0xdbc3, 0x3964, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x52cb, 0x73af, 0x6bae, 0x31a6, 
	0x2124, 0x630c, 0x73af, 0x52cb, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x3984, 0xd3a3, 0xfc23, 0xa2c3, 0x7bae, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xbdd7, 0x7a43, 0xfc23, 0xe3c3, 0x3964, 0xce59, 0x6b4c, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x52cb, 0x73af, 0x73cf, 
	0x634d, 0x73af, 0x5aeb, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x8c71, 0xc618, 0x3164, 0xdbc3, 0xfc23, 0x8a83, 0xc618, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xce79, 0x59c3, 0xbb43, 0x5a05, 0xc638, 0xffff, 0xf7be, 0x6b6d, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2124, 0x52aa, 0x73af, 
	0x73af, 0x52cb, 0x2124, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x8430, 0xf7be, 0xffff, 0xbdd7, 0x51e5, 0xbb43, 0x6a24, 0xdedb, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xa534, 0x52aa, 0xce79, 0xffff, 0xffff, 0xffff, 0xb5b6, 0x3943, 0x20e3, 0x18e3, 0x18e3, 0x18e3, 0x2103, 0x5acb, 
	0x5aeb, 0x2104, 0x18e3, 0x18e3, 0x18e3, 0x20e3, 0x3943, 0xa534, 0xffdf, 0xffff, 0xffff, 0xce59, 0x52aa, 0xad55, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xad55, 0x8284, 0xebe3, 0x9ac3, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x2104, 
	0x2104, 0x18e3, 0x18e3, 0x18e3, 0x18e3, 0x8a83, 0xebe3, 0x8284, 0xa514, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xad75, 0x6a03, 0xf403, 0xebe3, 0x59e3, 0x6b4d, 0x4a49, 0x2124, 0x18e3, 0x18e3, 
	0x18e3, 0x18e3, 0x2124, 0x4a69, 0x630c, 0x61e3, 0xebe3, 0xf403, 0x6a03, 0xa534, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x632c, 0xf403, 0xfc23, 0x6a24, 0xad55, 0xffff, 0xf7be, 0xe71c, 0xa514, 0x7bef, 
	0x7bef, 0xa514, 0xe71c, 0xf7be, 0xffdf, 0x9492, 0x61e3, 0xfc23, 0xf403, 0x5aeb, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xa514, 0x59e3, 0x6225, 0x9492, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0x8c51, 0x59e3, 0x6a24, 0x9cf3, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 
	0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff, 0xffff
};

void drawArrowUp(int16_t x0, int16_t y0, int16_t size, uint16_t color) 
{
  for (int16_t i = 0; i < size; i++) 
  {
    display.drawFastVLine(x0 + i, y0 + size - i, 2 * i + 1, color);
  }
}

void drawArrowDown(int16_t x0, int16_t y0, int16_t size, uint16_t color) 
{
  for (int16_t i = 0; i < size; i++) 
  {
    display.drawFastHLine(x0 - i, y0 - i, 2 * i + 1, color);
  }
}   

void setup() 
{
  Serial.begin(9600);
  display.begin();
}

void loop() 
{
  display.fillScreen(BLACK);
  for (int y = 0; y < SCREEN_HEIGHT; y++) 
  {
    for (int x = 0; x < SCREEN_WIDTH; x++) 
    {
      int index = y * SCREEN_WIDTH + x;
      display.drawPixel(x, y, logo[index]);
    }
  }

  delay(15000);
  display.fillScreen(BLACK);

  // Rysujemy dwie proste linie
  int x1 = SCREEN_WIDTH / 3; // x końca pierwszej linii (1/3 szerokości)
  int y1 = SCREEN_HEIGHT * 2 / 3; // y końca pierwszej linii (2/3 wysokości)

  // Pierwsza linia z strzałkami na końcach
  display.drawLine(0, y1, SCREEN_WIDTH, y1, RED); 
  display.drawLine(x1 - 5, 5, x1, 0, MAGENTA); // górna strzałka 
  display.drawLine(x1 + 5, 5, x1, 0, MAGENTA); // górna strzałka 
  display.drawLine(x1 - 5, SCREEN_HEIGHT - 6, x1, SCREEN_HEIGHT - 1, MAGENTA); // dolna strzałka
  display.drawLine(x1 + 5, SCREEN_HEIGHT - 6, x1, SCREEN_HEIGHT - 1, MAGENTA); // dolna strzałka

  // Druga linia z strzałkami na końcach
  display.drawLine(x1, SCREEN_HEIGHT-2, x1, 1, YELLOW);  // druga linia
  display.drawLine(SCREEN_WIDTH - 6, y1 - 5, SCREEN_WIDTH - 1, y1, CYAN); // Prawa strzałka
  display.drawLine(SCREEN_WIDTH - 6, y1 + 5, SCREEN_WIDTH - 1, y1, CYAN); // Prawa strzałka
  display.drawLine(5, y1 - 5, 0, y1, CYAN); // lewa strzałka
  display.drawLine(5, y1 + 5, 0, y1, CYAN); // lewa strzałka

  // Napis "64px" nad lewą strzałką pierwszej linii
  display.setTextSize(1);
  display.setTextColor(GREEN);
  display.setCursor(35, 8);
  display.print("64px");

  // Napis "96px" po prawej stronie drugiej linii
  display.setTextColor(BLUE);
  display.setCursor(66, 33);
  display.print("96px");

  delay(15000);
}

